==> openshift-model-storageversionmigrator-6.3.0-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageVersionMigrationFluentImpl.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StorageVersionMigrationFluentImpl<A extends StorageVersionMigrationFluent<A>> extends BaseFluent<A> implements StorageVersionMigrationFluent<A>{
  public StorageVersionMigrationFluentImpl() {
  }
  public StorageVersionMigrationFluentImpl(StorageVersionMigration instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private StorageVersionMigrationSpecBuilder spec;
  private StorageVersionMigrationStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public StorageVersionMigrationFluent.MetadataNested<A> withNewMetadata() {
    return new StorageVersionMigrationFluentImpl.MetadataNestedImpl();
  }
  public StorageVersionMigrationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new StorageVersionMigrationFluentImpl.MetadataNestedImpl(item);
  }
  public StorageVersionMigrationFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public StorageVersionMigrationFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public StorageVersionMigrationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StorageVersionMigrationSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public StorageVersionMigrationSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StorageVersionMigrationSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StorageVersionMigrationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public StorageVersionMigrationFluent.SpecNested<A> withNewSpec() {
    return new StorageVersionMigrationFluentImpl.SpecNestedImpl();
  }
  public StorageVersionMigrationFluent.SpecNested<A> withNewSpecLike(StorageVersionMigrationSpec item) {
    return new StorageVersionMigrationFluentImpl.SpecNestedImpl(item);
  }
  public StorageVersionMigrationFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public StorageVersionMigrationFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new StorageVersionMigrationSpecBuilder().build());
  }
  public StorageVersionMigrationFluent.SpecNested<A> editOrNewSpecLike(StorageVersionMigrationSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public StorageVersionMigrationStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public StorageVersionMigrationStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(StorageVersionMigrationStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new StorageVersionMigrationStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public StorageVersionMigrationFluent.StatusNested<A> withNewStatus() {
    return new StorageVersionMigrationFluentImpl.StatusNestedImpl();
  }
  public StorageVersionMigrationFluent.StatusNested<A> withNewStatusLike(StorageVersionMigrationStatus item) {
    return new StorageVersionMigrationFluentImpl.StatusNestedImpl(item);
  }
  public StorageVersionMigrationFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public StorageVersionMigrationFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new StorageVersionMigrationStatusBuilder().build());
  }
  public StorageVersionMigrationFluent.StatusNested<A> editOrNewStatusLike(StorageVersionMigrationStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageVersionMigrationFluentImpl that = (StorageVersionMigrationFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<StorageVersionMigrationFluent.MetadataNested<N>> implements StorageVersionMigrationFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) StorageVersionMigrationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends StorageVersionMigrationSpecFluentImpl<StorageVersionMigrationFluent.SpecNested<N>> implements StorageVersionMigrationFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(StorageVersionMigrationSpec item) {
      this.builder = new StorageVersionMigrationSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new StorageVersionMigrationSpecBuilder(this);
    }
    StorageVersionMigrationSpecBuilder builder;
    public N and() {
      return (N) StorageVersionMigrationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends StorageVersionMigrationStatusFluentImpl<StorageVersionMigrationFluent.StatusNested<N>> implements StorageVersionMigrationFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(StorageVersionMigrationStatus item) {
      this.builder = new StorageVersionMigrationStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new StorageVersionMigrationStatusBuilder(this);
    }
    StorageVersionMigrationStatusBuilder builder;
    public N and() {
      return (N) StorageVersionMigrationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> openshift-model-storageversionmigrator-6.7.2-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageVersionMigrationFluentImpl.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StorageVersionMigrationFluentImpl<A extends StorageVersionMigrationFluent<A>> extends BaseFluent<A> implements StorageVersionMigrationFluent<A>{
  public StorageVersionMigrationFluentImpl() {
  }
  public StorageVersionMigrationFluentImpl(StorageVersionMigration instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private StorageVersionMigrationSpecBuilder spec;
  private StorageVersionMigrationStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public StorageVersionMigrationFluentImpl.MetadataNested<A> withNewMetadata() {
    return new StorageVersionMigrationFluentImpl.MetadataNestedImpl();
  }
  public StorageVersionMigrationFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new StorageVersionMigrationFluentImpl.MetadataNestedImpl(item);
  }
  public StorageVersionMigrationFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public StorageVersionMigrationFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public StorageVersionMigrationFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StorageVersionMigrationSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public StorageVersionMigrationSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(StorageVersionMigrationSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new StorageVersionMigrationSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public StorageVersionMigrationFluentImpl.SpecNested<A> withNewSpec() {
    return new StorageVersionMigrationFluentImpl.SpecNestedImpl();
  }
  public StorageVersionMigrationFluentImpl.SpecNested<A> withNewSpecLike(StorageVersionMigrationSpec item) {
    return new StorageVersionMigrationFluentImpl.SpecNestedImpl(item);
  }
  public StorageVersionMigrationFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public StorageVersionMigrationFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new StorageVersionMigrationSpecBuilder().build());
  }
  public StorageVersionMigrationFluentImpl.SpecNested<A> editOrNewSpecLike(StorageVersionMigrationSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public StorageVersionMigrationStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public StorageVersionMigrationStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(StorageVersionMigrationStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new StorageVersionMigrationStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public StorageVersionMigrationFluentImpl.StatusNested<A> withNewStatus() {
    return new StorageVersionMigrationFluentImpl.StatusNestedImpl();
  }
  public StorageVersionMigrationFluentImpl.StatusNested<A> withNewStatusLike(StorageVersionMigrationStatus item) {
    return new StorageVersionMigrationFluentImpl.StatusNestedImpl(item);
  }
  public StorageVersionMigrationFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public StorageVersionMigrationFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new StorageVersionMigrationStatusBuilder().build());
  }
  public StorageVersionMigrationFluentImpl.StatusNested<A> editOrNewStatusLike(StorageVersionMigrationStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageVersionMigrationFluentImpl that = (StorageVersionMigrationFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<StorageVersionMigrationFluentImpl.MetadataNested<N>> implements StorageVersionMigrationFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) StorageVersionMigrationFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends StorageVersionMigrationSpecFluentImpl<StorageVersionMigrationFluentImpl.SpecNested<N>> implements StorageVersionMigrationFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(StorageVersionMigrationSpec item) {
      this.builder = new StorageVersionMigrationSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new StorageVersionMigrationSpecBuilder(this);
    }
    StorageVersionMigrationSpecBuilder builder;
    public N and() {
      return (N) StorageVersionMigrationFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends StorageVersionMigrationStatusFluentImpl<StorageVersionMigrationFluentImpl.StatusNested<N>> implements StorageVersionMigrationFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(StorageVersionMigrationStatus item) {
      this.builder = new StorageVersionMigrationStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new StorageVersionMigrationStatusBuilder(this);
    }
    StorageVersionMigrationStatusBuilder builder;
    public N and() {
      return (N) StorageVersionMigrationFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
